.. image:: https://readthedocs.org/projects/kappaml-core/badge/?version=latest
    :alt: ReadTheDocs
    :target: https://kappaml-core.readthedocs.io/en/stable/
.. image:: https://img.shields.io/pypi/v/kappaml-core.svg
    :alt: PyPI-Server
    :target: https://pypi.org/project/kappaml-core/
.. image:: https://img.shields.io/conda/vn/conda-forge/kappaml-core.svg
    :alt: Conda-Forge
    :target: https://anaconda.org/conda-forge/kappaml-core
.. image:: https://pepy.tech/badge/kappaml-core/month
    :alt: Monthly Downloads
    :target: https://pepy.tech/project/kappaml-core

============
kappaml-core
============


    Core library for the KappaML project.


This library implements experimental online automated machine learning algorithms for the KappaML project.


.. _pyscaffold-notes:

Note
====

This project has been set up using PyScaffold 4.1.4. For details and usage
information on PyScaffold see https://pyscaffold.org/.
